@@ -48,11 +48,11 @@ prepanel.default.xyplot <-
             dy <- diff(as.numeric(y[ord]))
             ## ok <- TRUE
         }
-        list(xlim = scale.limits(x), ylim = scale.limits(y), dx = dx, dy = dy)
+        list(xlim = scale.limits(x), ylim = scale.limits(y), dx = dx, dy = dy,
+             xat = if (is.factor(x)) sort(unique(as.numeric(x))) else NULL,
+             yat = if (is.factor(y)) sort(unique(as.numeric(y))) else NULL)
     }
-    else list(xlim = c(NA, NA),
-              ylim = c(NA, NA),
-              dx = NA, dy = NA)
+    else prepanel.null()
 }
 
 
@@ -405,8 +405,7 @@ xyplot.formula <-
           cond.orders(foo))
     foo[names(more.comp)] <- more.comp
 
-    if (is.null(foo$legend) && !is.null(groups) &&
-        (is.list(auto.key) || (is.logical(auto.key) && auto.key)))
+    if (is.null(foo$legend) && needAutoKey(auto.key, groups))
     {
         foo$legend <-
             list(list(fun = "drawSimpleKey",
